API error handling
This module converts service errors into HTTP responses with appropriate status codes and error messages.
Structs
- ApiError
- API error type that can be converted to HTTP responses
- Error
Response - Error response JSON structure
Type Aliases
- ApiResult
- Result type for API handlers